summaryrefslogtreecommitdiffstats
path: root/agent/listeneradapter_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'agent/listeneradapter_p.h')
-rw-r--r--agent/listeneradapter_p.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/agent/listeneradapter_p.h b/agent/listeneradapter_p.h
index 4bf754694..ed85f0470 100644
--- a/agent/listeneradapter_p.h
+++ b/agent/listeneradapter_p.h
@@ -1,5 +1,5 @@
/*
* This file is part of the Polkit-qt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -23,9 +23,9 @@
#include <TQtCore/TQObject>
-#include "polkitqt1-agent-listener.h"
-#include "polkitqt1-identity.h"
-#include "polkitqt1-details.h"
+#include "polkittqt1-agent-listener.h"
+#include "polkittqt1-identity.h"
+#include "polkittqt1-details.h"
typedef struct _GList GList;
typedef struct _GCancellable GCancellable;
@@ -51,7 +51,7 @@ public:
static ListenerAdapter* instance();
~ListenerAdapter() {}
- void polkit_qt_listener_initiate_authentication(PolkitAgentListener *listener,
+ void polkit_tqt_listener_initiate_authentication(PolkitAgentListener *listener,
const gchar *action_id,
const gchar *message,
const gchar *icon_name,
@@ -61,7 +61,7 @@ public:
GCancellable *cancellable,
GSimpleAsyncResult *result);
- gboolean polkit_qt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
+ gboolean polkit_tqt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
GAsyncResult *res,
GError **error);
void cancelled_cb(PolkitAgentListener *listener);
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*